import { addSchema } from "@soft-stech/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@soft-stech/base";
import { register } from "@soft-stech/validate";
const schemaId = "rabbitmq.com.v1beta1.Binding";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "rabbitmq.com/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Binding"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "arguments": {
                    "type": "object",
                    "properties": {},
                    "nullable": true
                },
                "destination": {
                    "type": "string",
                    "nullable": true
                },
                "destinationType": {
                    "enum": [
                        "exchange",
                        "queue"
                    ],
                    "type": "string",
                    "nullable": true
                },
                "rabbitmqClusterReference": {
                    "properties": {
                        "connectionSecret": {
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "type": "object",
                            "nullable": true
                        },
                        "name": {
                            "type": "string",
                            "nullable": true
                        },
                        "namespace": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "routingKey": {
                    "type": "string",
                    "nullable": true
                },
                "source": {
                    "type": "string",
                    "nullable": true
                },
                "vhost": {
                    "default": "/",
                    "type": "string",
                    "nullable": true
                }
            },
            "required": [
                "rabbitmqClusterReference"
            ],
            "type": "object",
            "nullable": true
        },
        "status": {
            "properties": {
                "conditions": {
                    "items": {
                        "properties": {
                            "lastTransitionTime": {
                                "format": "date-time",
                                "type": "string",
                                "nullable": true
                            },
                            "message": {
                                "type": "string",
                                "nullable": true
                            },
                            "reason": {
                                "type": "string",
                                "nullable": true
                            },
                            "status": {
                                "type": "string"
                            },
                            "type": {
                                "type": "string"
                            }
                        },
                        "required": [
                            "status",
                            "type"
                        ],
                        "type": "object"
                    },
                    "type": "array",
                    "nullable": true
                },
                "observedGeneration": {
                    "format": "int64",
                    "type": "integer",
                    "nullable": true
                }
            },
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
/**
 * Binding is the Schema for the bindings API
 */
export class Binding extends Model {
    constructor(data) {
        super({
            apiVersion: Binding.apiVersion,
            kind: Binding.kind,
            ...data
        });
    }
}
Binding.apiVersion = "rabbitmq.com/v1beta1";
Binding.kind = "Binding";
Binding.is = createTypeMetaGuard(Binding);
setSchema(Binding, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
