import { addSchema } from "@soft-stech/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@soft-stech/base";
import { register } from "@soft-stech/validate";
const schemaId = "rabbitmq.com.v1beta1.Queue";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "rabbitmq.com/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Queue"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "arguments": {
                    "type": "object",
                    "properties": {},
                    "nullable": true
                },
                "autoDelete": {
                    "type": "boolean",
                    "nullable": true
                },
                "durable": {
                    "type": "boolean",
                    "nullable": true
                },
                "name": {
                    "type": "string"
                },
                "rabbitmqClusterReference": {
                    "properties": {
                        "connectionSecret": {
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "type": "object",
                            "nullable": true
                        },
                        "name": {
                            "type": "string",
                            "nullable": true
                        },
                        "namespace": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "type": {
                    "type": "string",
                    "nullable": true
                },
                "vhost": {
                    "default": "/",
                    "type": "string",
                    "nullable": true
                }
            },
            "required": [
                "name",
                "rabbitmqClusterReference"
            ],
            "type": "object",
            "nullable": true
        },
        "status": {
            "properties": {
                "conditions": {
                    "items": {
                        "properties": {
                            "lastTransitionTime": {
                                "format": "date-time",
                                "type": "string",
                                "nullable": true
                            },
                            "message": {
                                "type": "string",
                                "nullable": true
                            },
                            "reason": {
                                "type": "string",
                                "nullable": true
                            },
                            "status": {
                                "type": "string"
                            },
                            "type": {
                                "type": "string"
                            }
                        },
                        "required": [
                            "status",
                            "type"
                        ],
                        "type": "object"
                    },
                    "type": "array",
                    "nullable": true
                },
                "observedGeneration": {
                    "format": "int64",
                    "type": "integer",
                    "nullable": true
                }
            },
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
/**
 * Queue is the Schema for the queues API
 */
export class Queue extends Model {
    constructor(data) {
        super({
            apiVersion: Queue.apiVersion,
            kind: Queue.kind,
            ...data
        });
    }
}
Queue.apiVersion = "rabbitmq.com/v1beta1";
Queue.kind = "Queue";
Queue.is = createTypeMetaGuard(Queue);
setSchema(Queue, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
