import { addSchema } from "@soft-stech/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@soft-stech/base";
import { register } from "@soft-stech/validate";
const schemaId = "rabbitmq.com.v1beta1.User";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "rabbitmq.com/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "User"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "importCredentialsSecret": {
                    "properties": {
                        "name": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object",
                    "nullable": true
                },
                "rabbitmqClusterReference": {
                    "properties": {
                        "connectionSecret": {
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "type": "object",
                            "nullable": true
                        },
                        "name": {
                            "type": "string",
                            "nullable": true
                        },
                        "namespace": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "tags": {
                    "items": {
                        "enum": [
                            "management",
                            "policymaker",
                            "monitoring",
                            "administrator"
                        ],
                        "type": "string"
                    },
                    "type": "array",
                    "nullable": true
                }
            },
            "required": [
                "rabbitmqClusterReference"
            ],
            "type": "object",
            "nullable": true
        },
        "status": {
            "properties": {
                "conditions": {
                    "items": {
                        "properties": {
                            "lastTransitionTime": {
                                "format": "date-time",
                                "type": "string",
                                "nullable": true
                            },
                            "message": {
                                "type": "string",
                                "nullable": true
                            },
                            "reason": {
                                "type": "string",
                                "nullable": true
                            },
                            "status": {
                                "type": "string"
                            },
                            "type": {
                                "type": "string"
                            }
                        },
                        "required": [
                            "status",
                            "type"
                        ],
                        "type": "object"
                    },
                    "type": "array",
                    "nullable": true
                },
                "credentials": {
                    "properties": {
                        "name": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object",
                    "nullable": true
                },
                "observedGeneration": {
                    "format": "int64",
                    "type": "integer",
                    "nullable": true
                },
                "username": {
                    "type": "string"
                }
            },
            "required": [
                "username"
            ],
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
/**
 * User is the Schema for the users API.
 */
export class User extends Model {
    constructor(data) {
        super({
            apiVersion: User.apiVersion,
            kind: User.kind,
            ...data
        });
    }
}
User.apiVersion = "rabbitmq.com/v1beta1";
User.kind = "User";
User.is = createTypeMetaGuard(User);
setSchema(User, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
